
import iwork.eheap2.*;

import com.cycling74.max.*;

/**
 * Implements a Max/MSP object to receive Dance mat events from the Event Heap
 */
public class DanceEHMax extends MaxObject implements EventCallback {
	
	EventHeap eh;

	
	/*
	 * Initializes the outlets and the Dance object
	 */
	public DanceEHMax() {
		
		post("Initializing Event Heap...");
		eh = new EventHeap("localhost");

		post("Initializing Dance mat object...");
		declareOutlets(new int[]{
				DataTypes.INT, // Rhythm to play
				DataTypes.INT, // Key to play
				DataTypes.INT, // Combo to play
				DataTypes.INT, // Chord to play
				DataTypes.INT}); // Key to stop
		
		try {
			Event templates[] = new Event[6];
			templates[0] = new Event(DanceEHUtils.EVENT_PLAYCOMBO);
			templates[1] = new Event(DanceEHUtils.EVENT_PLAYKEY);
			templates[2] = new Event(DanceEHUtils.EVENT_STARTRHYTHM);
			templates[3] = new Event(DanceEHUtils.EVENT_STOPRHYTHM);
			templates[4] = new Event(DanceEHUtils.EVENT_PLAYCHORD);
			templates[5] = new Event(DanceEHUtils.EVENT_STOPKEY);
			eh.registerForEvents(templates, this);
		} catch (EventHeapException ex) {
			ex.printStackTrace();
		}
		
		
	}

	public boolean returnEvent(Event[] ev) {
		try {
			String type = ev[0].getEventType();
			if (type.equals(DanceEHUtils.EVENT_PLAYCOMBO)) {
				Integer comboId = (Integer) ev[0].getPostValue("comboId");
				playCombo(comboId.intValue());

			} else if(type.equals(DanceEHUtils.EVENT_PLAYCHORD)) {
				Integer chordId = (Integer) ev[0].getPostValue("chordId");
				playChord(chordId.intValue());
				
				
			} else if(type.equals(DanceEHUtils.EVENT_PLAYKEY)) {
				Integer keyId = (Integer) ev[0].getPostValue("keyId");
				playKey(keyId.intValue());

			} else if(type.equals(DanceEHUtils.EVENT_STOPKEY)) {
				Integer keyId = (Integer) ev[0].getPostValue("keyId");
				stopKey( keyId.intValue());
				
			} else if(type.equals(DanceEHUtils.EVENT_STARTRHYTHM)) {
				Integer rhythmId = (Integer) ev[0].getPostValue("rhythmId");
				startRhythm(rhythmId.intValue());
				
			} else if(type.equals(DanceEHUtils.EVENT_STOPRHYTHM)) {
				stopRhythm();
			}
		} catch (EventHeapException ex) {
			ex.printStackTrace();
		}
		
		return true;
	}
	
	/* (non-Javadoc)
	 * @see DanceOutput#startRhythm(int)
	 */
	public void startRhythm(int rhythm) {
		outlet(0,rhythm);
		post("Playing rhythm " + rhythm);
		
	}

	/* (non-Javadoc)
	 * @see DanceOutput#stopRhythm()
	 */
	public void stopRhythm() {
		outlet(0,9);
		post("Stopping rhythm");
		
	}

	/* (non-Javadoc)
	 * @see DanceOutput#playKey(int)
	 */
	public void playKey(int key) {
		outlet(1,key);
		post("Playing key " + key);
		// Send a 0 to close the switch on the MAX patch
		outlet(1,0);

	}

	/* (non-Javadoc)
	 * @see DanceOutput#playCombo(int)
	 */
	public void playCombo(int combo) {
		outlet(2, combo);
		post("Playing combo " + combo);
	}

	/* (non-Javadoc)
	 * @see DanceOutput#playCombo(int)
	 */
	public void playChord(int chord) {
		outlet(3, chord);
		post("Playing chord " + chord);
		// Send a 0 to close the switch on the MAX patch
		outlet(3,0);
	}

	/* (non-Javadoc)
	 * @see DanceOutput#stopKeys()
	 */
	public void stopKey(int key) {
		outlet(4, key);
		post("Stopping key" + key);
		// Send a 0 to close the switch on the MAX patch
		outlet(4, 0);
	}
	
	
}
